@@ -11,6 +11,7 @@ S64         = 6   # signed 64bit integer
 FLOAT64     = 7   # IEEE754 64bit signed float.
 DECIMAL     = 8   # Arbitrary Precision decimals.
 SCHED       = 9   # Datetime with tz/offset/subsec etc.  for future times.
+BASICDATE   = 10  # day/month/year values (no TZ stuff)  for future times and/or datestamps.
 #                 # 10/11/12 reserved for future use
 LIST        = 13  # (d) list-like composite object
 DICT        = 14  # (e) dict-like composite object
@@ -41,6 +42,7 @@ DATATYPE_NAMES = {
     7: "FLOAT64",
     8: "DECIMAL",
     9: "SCHED",
+    10: "BASICDATE",
     13: "LIST",
     14: "DICT",
     15: "B3_RESERVED_15",
