@@ -110,6 +110,46 @@ def test_dec_number(desc, ttype, tvalue, tbytes):
     assert data_type == ttype
     assert value == tvalue
 
+# --------------------------------------------------------------------------------------------------
+
+# Basicdate tests
+
+def test_enc_basicdate():
+    tbytes = SBytes("a8 04 18 09 cc 1f")      # typ BASICDATA, sz 4, 24 sept 2022
+    val = datetime.date(year=2022, month=9, day=24)
+    assert encode_item_joined(key=None, data_type=BASICDATE, value=val) == tbytes
+
+def test_dec_basicdate():
+    tbytes = SBytes("a8 04 18 09 cc 1f")      # typ BASICDATA, sz 4, 24 sept 2022
+    data_type, value = decode_item_type_value(tbytes)
+    assert data_type == BASICDATE
+    assert value == datetime.date(year=2022, month=9, day=24)
+
+def test_roundtrip_basicdate():
+    tval = datetime.date(year=2022, month=9, day=24)
+    tbytes = encode_item_joined(key=None, data_type=BASICDATE, value=tval)
+    data_type, val = decode_item_type_value(tbytes)
+    assert data_type == BASICDATE
+    assert tval == val
+
+
+def test_dec_basicdate_bad_day():
+    tbytes = SBytes("a8 04 45 09 cc 1f")      # bad day value
+    with pytest.raises(ValueError, match="day is out of range"):
+        decode_item_type_value(tbytes)
+
+def test_dec_basicdate_bad_size_1():
+    tbytes = SBytes("a8 02 45 09 cc 1f")      # tlv size 2, should be 4
+    with pytest.raises(ValueError, match="basicdate data size"):
+        decode_item_type_value(tbytes)
+
+def test_dec_basicdate_bad_size_2():
+    tbytes = SBytes("a8 08 45 09 cc 1f")      # tlv size 8, should be 4
+    with pytest.raises(ValueError, match="basicdate data size"):
+        decode_item_type_value(tbytes)
+
+
+
 
 # --------------------------------------------------------------------------------------------------
 
