@@ -1,9 +1,12 @@
 # Codecs for basic/simple types
 
-import struct, math
+import struct, math, datetime
 
-from b3.utils import VALID_INT_TYPES, VALID_STR_TYPES
+from six import int2byte
+
+from b3.utils import VALID_INT_TYPES, VALID_STR_TYPES, IntByteAt
 from b3.datatypes import U64, S64, DATATYPE_NAMES
+from b3.type_varint import encode_svarint, decode_svarint
 
 # Method: Encoders assemble lists of byte-buffers, then b"".join() them.
 #         We take advantage of this often for empty/nonexistant fields etc.
@@ -66,6 +69,26 @@ def decode_complex(buf, index, end):
     return complex(*struct.unpack("<dd", buf[index : index + 16]))
 
 
+
+# In: a python datetime.date object (timezone info is ignored)
+
+def encode_basicdate(value):
+    if not isinstance(value, datetime.date):
+        raise TypeError("BASICDATE only accepts datetime.date values")
+    out = [int2byte(value.day), int2byte(value.month), encode_svarint(value.year)]
+    return b"".join(out)
+
+
+def decode_basicdate(buf, index, end):
+    day, index = IntByteAt(buf, index)
+    month, index = IntByteAt(buf, index)
+    year, index = decode_svarint(buf, index)
+    if index != end:
+        raise ValueError("mismatch between tlv field size and basicdate data size")
+    return datetime.date(year=year, month=month, day=day)
+
+
+
 # Note: the 'end' parameter for the decoders is the index of the start of the NEXT object, which == out object's SIZE if index==0
 #         so yes, decode(blah, 0, len(blah)) is correct when testing.
 #         and index==end means there is no data at all.
